#' Make an ELT in memory
#'
#' @description
#' This code does nothing at all. But the example shows how to make an ELT in memory.
#'
#' @returns
#' Nothing.
#'
#' @details
#' This code just exists as a way to present the example.
#'
#' @author
#' Stephen Jewson \email{stephen.jewson@gmail.com}
#'
#' @example man/examples/example_003_make_elt.R
#'
#' @export
#'
make_elt=function(){
	message("This code does nothing.\n")
	message("It just exists as a way to present the example.\n")
}
