#' A template for R code
#'
#' @description
#' Longer description here
#'
#' @param x		Input parameter \code{x}
#'
#' @returns
#' Something
#'
#' @details
#' Does something.
#'
#' More details here.
#'
#' @author
#' Stephen Jewson \email{stephen.jewson@gmail.com}
#'
#' @seealso
#'\itemize{
#'\item \code{something else} 	Does something else
#'}
#'
#' @example man/examples/example_215_nahu_k2020_rates_interpolation.R
#'
#' @export
#'
template=function(x){
	message("Hello world, from inside the template.\n")
}
